@@ -329,7 +329,8 @@ def main():
     logging.basicConfig(level=logging.INFO, format='[%(asctime)s] %(levelname)s - %(message)s')
     arg_parser = argparse.ArgumentParser(
         description='Quickly launch an EC2 instance for small tasks. The instance\'s '
-                    'lifecycle is tied to the process, enabling easy Ctrl+C instance termination when done.'
+                    'lifecycle is tied to the process, enabling easy Ctrl+C instance termination when done.',
+        epilog='help & support:\n  https://github.com/personalcomputer/ec2instance/issues'
     )
     arg_parser.add_argument('-t', '--type', type=str, default=DEFAULT_INSTANCE_TYPE, dest='instance_type',
                             help=f'EC2 instance type. (default: {DEFAULT_INSTANCE_TYPE})')
@@ -354,7 +355,6 @@ def main():
                             'storing local data and configuration.')
     arg_parser.add_argument('--delete-sandbox', action='store_true', help='Delete the persistent VPC & keypair '
                             'created by ec2instance.')
-
     args = arg_parser.parse_args()
 
     if args.show_data_path:
